/*
 ~ Copyright 2006-2007 Nicolas De Loof.
 ~
 ~ Licensed under the Apache License, Version 2.0 (the "License");
 ~ you may not use this file except in compliance with the License.
 ~ You may obtain a copy of the License at
 ~
 ~      http://www.apache.org/licenses/LICENSE-2.0
 ~
 ~ Unless required by applicable law or agreed to in writing, software
 ~ distributed under the License is distributed on an "AS IS" BASIS,
 ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ~ See the License for the specific language governing permissions and
 ~ limitations under the License.
 */
package info.jmonit.logger;

import java.util.logging.Level;


/**
 * Logger implementation based on Java 1.4+ logging API.
 * @author <a href="mailto:ndeloof@sourceforge.net">ndeloof</a>
 */
public class Java14Logger
    implements Logger
{
    /** Delegate java 1.4 logger */
    private java.util.logging.Logger logger;

    /**
     * Constructor
     * @param target logging class
     */
    public Java14Logger( Class target )
    {
        super();
        logger = java.util.logging.Logger.getLogger( target.getName() );
    }

    /**
     * {@inheritDoc}
     *
     * @see info.jmonit.logger.Logger#debug(java.lang.String)
     */
    public void debug( String message )
    {
        logger.log( Level.FINE, message );
    }

    /**
     * {@inheritDoc}
     * @see info.jmonit.logger.Logger#info(java.lang.String)
     */
    public void info( String message )
    {
        logger.log( Level.INFO, message );
    }

    /**
     * {@inheritDoc}
     * @see info.jmonit.logger.Logger#error(java.lang.String)
     */
    public void error( String message )
    {
        logger.log( Level.SEVERE, message );
    }

    /**
     * {@inheritDoc}
     *
     * @see info.jmonit.logger.Logger#error(java.lang.String, java.lang.Exception)
     */
    public void error( String message, Exception e )
    {
        logger.log( Level.SEVERE, message, e );
    }

    /**
     * {@inheritDoc}
     * @see info.jmonit.logger.Logger#isDebugEnabled()
     */
    public boolean isDebugEnabled()
    {
        return logger.isLoggable( Level.FINE );
    }

    /**
     * {@inheritDoc}
     * @see info.jmonit.logger.Logger#warn(java.lang.String)
     */
    public void warn( String message )
    {
        logger.log( Level.WARNING, message );
    }

    /**
     * {@inheritDoc}
     *
     * @see info.jmonit.logger.Logger#warn(java.lang.String, java.lang.Exception)
     */
    public void warn( String message, Exception e )
    {
        logger.log( Level.WARNING, message, e );
    }
}
