/*
 ~ Copyright 2006-2007 Nicolas De Loof.
 ~
 ~ Licensed under the Apache License, Version 2.0 (the "License");
 ~ you may not use this file except in compliance with the License.
 ~ You may obtain a copy of the License at
 ~
 ~      http://www.apache.org/licenses/LICENSE-2.0
 ~
 ~ Unless required by applicable law or agreed to in writing, software
 ~ distributed under the License is distributed on an "AS IS" BASIS,
 ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ~ See the License for the specific language governing permissions and
 ~ limitations under the License.
 */
package info.jmonit.logger;

import info.jmonit.config.runtime.FactorySupport;
import info.jmonit.config.runtime.RuntimeDiscovery;

/**
 * Factory for loggers.
 *
 * @author <a href="mailto:ndeloof@sourceforge.net">ndeloof</a>
 */
public class LoggerFactory
    extends FactorySupport
{
    /** Flag for first attempt to create a logger */
    private static boolean first = true;

    /**
     * Create a logger for the target class.
     *
     * @param clazz target logging class
     * @return Logger implementation
     */
    public static Logger getLogger( Class clazz )
    {
        if ( RuntimeDiscovery.isLog4j() )
        {
            return (Logger) silentlyCreate( "info.jmonit.logger.Log4jLogger", new Object[] { clazz } );
        }
        if ( RuntimeDiscovery.isCommonsLogging() )
        {
            return (Logger) silentlyCreate( "info.jmonit.logger.CommonsLoggingLogger", new Object[] { clazz } );
        }
        if ( System.getProperty( ConsoleLogger.LEVEL ) != null )
        {
            return new ConsoleLogger( clazz );
        }
        if ( RuntimeDiscovery.isJava14() )
        {
            return (Logger) silentlyCreate( "info.jmonit.logger.Java14Logger", new Object[] { clazz } );
        }
        if ( first )
        {
            first = false;
            System.err.println( "WARNING : no supported logging API available. jMonit will not produce logs" );
        }
        return new NullLogger();
    }
}
