/*
 ~ Copyright 2006-2007 Nicolas De Loof.
 ~
 ~ Licensed under the Apache License, Version 2.0 (the "License");
 ~ you may not use this file except in compliance with the License.
 ~ You may obtain a copy of the License at
 ~
 ~      http://www.apache.org/licenses/LICENSE-2.0
 ~
 ~ Unless required by applicable law or agreed to in writing, software
 ~ distributed under the License is distributed on an "AS IS" BASIS,
 ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ~ See the License for the specific language governing permissions and
 ~ limitations under the License.
 */
package info.jmonit.monitor;

import info.jmonit.Probe;


/**
 * Probe implementation that does nothing. Used for disabled Monitors or in case
 * of bad API usage, to avoid NullPointerException.
 *
 * @author <a href="mailto:ndeloof@sourceforge.net">ndeloof</a>
 */
public class NullProbe
    implements Probe
{

    /**
     * Constructor
     */
    public NullProbe()
    {
        super();
    }

    /**
     * {@inheritDoc}
     *
     * @see info.jmonit.Probe#cancel()
     */
    public void cancel()
    {
        // Nop
    }

    /**
     * {@inheritDoc}
     *
     * @see info.jmonit.Probe#getElapsedTime()
     */
    public long getElapsedTime()
    {
        return 0;
    }

    /**
     * {@inheritDoc}
     *
     * @see info.jmonit.Probe#pause()
     */
    public void pause()
    {
        // Nop
    }

    /**
     * {@inheritDoc}
     *
     * @see info.jmonit.Probe#resume()
     */
    public void resume()
    {
        // Nop
    }

    /**
     * {@inheritDoc}
     *
     * @see info.jmonit.Probe#start()
     */
    public long start()
    {
        return 0;
    }

    /**
     * {@inheritDoc}
     *
     * @see info.jmonit.Probe#startedAt()
     */
    public long startedAt()
    {
        return 0;
    }

    /**
     * {@inheritDoc}
     *
     * @see info.jmonit.Probe#stop()
     */
    public long stop()
    {
        return 0;
    }

}
