/*
 ~ Copyright 2006-2007 Nicolas De Loof.
 ~
 ~ Licensed under the Apache License, Version 2.0 (the "License");
 ~ you may not use this file except in compliance with the License.
 ~ You may obtain a copy of the License at
 ~
 ~      http://www.apache.org/licenses/LICENSE-2.0
 ~
 ~ Unless required by applicable law or agreed to in writing, software
 ~ distributed under the License is distributed on an "AS IS" BASIS,
 ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ~ See the License for the specific language governing permissions and
 ~ limitations under the License.
 */
package info.jmonit.proxy;

import java.lang.reflect.Modifier;

import info.jmonit.logger.Logger;
import info.jmonit.logger.LoggerFactory;

/**
 * Use CGlib bytecode generator to create en enhancer proxy for target object.
 * 
 * @author <a href="mailto:ndeloof@sourceforge.net">ndeloof</a>
 */
public class CGlibMonitoredProxyFactory
    extends MonitoredProxyFactory
{
    /** Logger */
    private static Logger logger = LoggerFactory.getLogger( CGlibMonitoredProxyFactory.class );

    /**
     * {@inheritDoc}
     * @see info.jmonit.proxy.MonitoredProxyFactory#createMonitoredClassProxy(java.lang.Object, java.lang.String)
     */
    public Object createMonitoredClassProxy( Object target, String domain )
    {
        if ( ( target.getClass().getModifiers() & Modifier.FINAL ) == 0 )
        {
            logger.warn( "Cannot create CGlib proxy for final class " + target.getClass().getName() );
            return target;
        }
        
        if ( logger.isDebugEnabled() )
        {
            logger.debug( "Create CGlib proxy for " + target.getClass().getName() );
        }
        
//        Class cls = Enhancer.enhance(thisClass, interfaces, nullInterceptor, loader).getClass();
        return target;
    }

}
