/*
 ~ Copyright 2006-2007 Nicolas De Loof.
 ~
 ~ Licensed under the Apache License, Version 2.0 (the "License");
 ~ you may not use this file except in compliance with the License.
 ~ You may obtain a copy of the License at
 ~
 ~      http://www.apache.org/licenses/LICENSE-2.0
 ~
 ~ Unless required by applicable law or agreed to in writing, software
 ~ distributed under the License is distributed on an "AS IS" BASIS,
 ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ~ See the License for the specific language governing permissions and
 ~ limitations under the License.
 */
package info.jmonit.proxy;

import info.jmonit.config.runtime.FactorySupport;
import info.jmonit.config.runtime.RuntimeDiscovery;
import info.jmonit.logger.Logger;
import info.jmonit.logger.LoggerFactory;

/**
 * @author <a href="mailto:ndeloof@sourceforge.net">ndeloof</a>
 *
 */
public class DefaultMonitoredProxyFactory
    extends MonitoredProxyFactory
{
    /** Factory class name to build CGLib proxies */
    private static final String CGLIB_PROXY = "info.jmonit.proxy.CglibMonitoredProxyFactory";

    /** Logger */
    private static Logger logger = LoggerFactory.getLogger( DefaultMonitoredProxyFactory.class );

    /** Runtime discovered Class enhacer proxy factory */
    private static MonitoredProxyFactory factory;
    static 
    {
        if ( RuntimeDiscovery.isCglib() )
        {
            factory = (MonitoredProxyFactory) FactorySupport.silentlyCreate( CGLIB_PROXY );
        }
    }
    
    /**
     * {@inheritDoc}
     * 
     * @see info.jmonit.proxy.MonitoredProxyFactory#createMonitoredClassProxy(java.lang.Object, java.lang.String)
     */
    public Object createMonitoredClassProxy( Object target, String domain )
    {
        if ( factory == null )
        {
            logger.warn( "No bytecode generator found in classpath. Cannot create a proxy for "
                         + target.getClass().getName() );
            return target;
        }
        return factory.createMonitoredClassProxy( target, domain );
    }
}
