/*
 ~ Copyright 2006-2007 Nicolas De Loof.
 ~
 ~ Licensed under the Apache License, Version 2.0 (the "License");
 ~ you may not use this file except in compliance with the License.
 ~ You may obtain a copy of the License at
 ~
 ~      http://www.apache.org/licenses/LICENSE-2.0
 ~
 ~ Unless required by applicable law or agreed to in writing, software
 ~ distributed under the License is distributed on an "AS IS" BASIS,
 ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ~ See the License for the specific language governing permissions and
 ~ limitations under the License.
 */
package info.jmonit.proxy;

import info.jmonit.Monitoring;
import info.jmonit.Probe;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;

/**
 * @author <a href="mailto:ndeloof@sourceforge.net">ndeloof</a>
 *
 */
public class MonitoredInvocationHandler
    implements InvocationHandler
{
    
    /** Monitoring domain for proxied object */
    private String domain;
    
    /** Target object to be monitored */
    private Object target;
    
    /**
     * @param domain Monitor domain
     * @param target monitored object
     */
    public MonitoredInvocationHandler( String domain, Object target )
    {
        super();
        this.domain = domain;
        this.target = target;
    }

    /**
     * 
     * {@inheritDoc}
     * @see java.lang.reflect.InvocationHandler#invoke(java.lang.Object, java.lang.reflect.Method, java.lang.Object[])
     */
    public Object invoke( Object proxy, Method method, Object[] args )
        throws Throwable
    {
        Probe probe = Monitoring.start( domain, method.getName() );
        try 
        {
            return method.invoke( target, args );
        }
        finally
        {
            probe.stop();
        }
    }

}
