/*
 ~ Copyright 2006-2007 Nicolas De Loof.
 ~
 ~ Licensed under the Apache License, Version 2.0 (the "License");
 ~ you may not use this file except in compliance with the License.
 ~ You may obtain a copy of the License at
 ~
 ~      http://www.apache.org/licenses/LICENSE-2.0
 ~
 ~ Unless required by applicable law or agreed to in writing, software
 ~ distributed under the License is distributed on an "AS IS" BASIS,
 ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ~ See the License for the specific language governing permissions and
 ~ limitations under the License.
 */
package info.jmonit.proxy;

import info.jmonit.logger.Logger;
import info.jmonit.logger.LoggerFactory;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Proxy;

/**
 * @author <a href="mailto:ndeloof@sourceforge.net">ndeloof</a>
 *
 */
public abstract class MonitoredProxyFactory
{
    /** Logger */
    private static Logger logger = LoggerFactory.getLogger( MonitoredProxyFactory.class );

    /**
     * Create a proxy for monitoring the target object.
     * 
     * @param target object to be monitored
     * @param domain target domain
     * @return monitored proxy
     */
    public Object createMonitoredProxy( Object target, String domain )
    {
        Class[] interfaces = target.getClass().getInterfaces();
        if ( interfaces.length == 0 )
        {
            return createMonitoredClassProxy( target, domain );
        }
        return createMonitoredProxy( target, interfaces, domain );
    }

    /**
     * Create a proxy for monitoring the target object based on runtime byte-code 
     * generation.
     * 
     * @param target object to be monitored
     * @param domain target domain
     * @return monitored proxy
     */
    public abstract Object createMonitoredClassProxy( Object target, String domain );
    
    /**
     * 
     * @param target object to be monitored
     * @param interfaces interfaces to be implemented
     * @param domain target domain
     * @return monitored proxy
     */
    public Object createMonitoredProxy( Object target, Class[] interfaces, String domain )
    {
        ClassLoader cl = Thread.currentThread().getContextClassLoader();
        if ( cl == null )
        {
            cl = getClass().getClassLoader();
        }
        
        if ( logger.isDebugEnabled() )
        {
            logger.debug( "Create reflect proxy for " + target.getClass().getName() );
        }
        InvocationHandler handler = new MonitoredInvocationHandler( domain, target );
        return Proxy.newProxyInstance( cl, interfaces, handler );
    }
}
