/*
 ~ Copyright 2006-2007 Nicolas De Loof.
 ~
 ~ Licensed under the Apache License, Version 2.0 (the "License");
 ~ you may not use this file except in compliance with the License.
 ~ You may obtain a copy of the License at
 ~
 ~      http://www.apache.org/licenses/LICENSE-2.0
 ~
 ~ Unless required by applicable law or agreed to in writing, software
 ~ distributed under the License is distributed on an "AS IS" BASIS,
 ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ~ See the License for the specific language governing permissions and
 ~ limitations under the License.
 */
package info.jmonit.visitor;


import java.util.Date;

/**
 * A consistent view of the monitor state.
 *
 * @author <a href="mailto:ndeloof@sourceforge.net">ndeloof</a>
 */
public final class MonitorSnapshot
{
    /**
     * Constructor
     * @param source Monitoring to build a shapshot
     */
    public MonitorSnapshot( SnapshotSource source )
    {
        super();
        this.hits = source.getHits();
        this.total = source.getTotal();
        this.min = source.getMin();
        this.max = source.getMax();
        this.active = source.getActive();
        this.load = source.getLoad();
        this.maxActive = source.getMaxActive();
        this.lastUse = new Date( source.getLastUse() );
        this.firstUse = new Date( source.getFirstUse() );
    }

    /** number of time the monitor was used */
    protected long hits;

    /** total values added */
    protected long total;

    /** min value */
    protected long min;

    /** max value */
    protected long max;

    /** active threads running the monitor */
    protected long active;

    /** average active threads running the monitor */
    protected double load;

    /** max active threads running the monitor */
    protected long maxActive;

    /** last use */
    protected Date lastUse;

    /** first use */
    protected Date firstUse;

    /**
     * @return the active
     */
    public long getActive()
    {
        return active;
    }

    /**
     * @return the hits
     */
    public long getHits()
    {
        return hits;
    }

    /**
     * @return the lastUse
     */
    public Date getLastUse()
    {
        return lastUse;
    }

    /**
     * @return the firstUse
     */
    public Date getFirstUse()
    {
        return firstUse;
    }

    /**
     * @return the max
     */
    public long getMax()
    {
        return max;
    }

    /**
     * @return the maxActive
     */
    public long getMaxActive()
    {
        return maxActive;
    }

    /**
     * @return the min
     */
    public long getMin()
    {
        return min;
    }

    /**
     * @return the total
     */
    public long getTotal()
    {
        return total;
    }

    /**
     * {@inheritDoc}
     *
     * @see info.jmonit.monitor.report.Snapshot#getAverage()
     */
    public double getAverage()
    {
        if ( hits == 0 )
        {
            return 0D;
        }
        return ( (double) total ) / hits;
    }

    /**
     * {@inheritDoc}
     *
     * @see info.jmonit.monitor.report.Snapshot#getLoad()
     */
    public double getLoad()
    {
        return load;
    }
}