/*
 ~ Copyright 2006-2007 Nicolas De Loof.
 ~
 ~ Licensed under the Apache License, Version 2.0 (the "License");
 ~ you may not use this file except in compliance with the License.
 ~ You may obtain a copy of the License at
 ~
 ~      http://www.apache.org/licenses/LICENSE-2.0
 ~
 ~ Unless required by applicable law or agreed to in writing, software
 ~ distributed under the License is distributed on an "AS IS" BASIS,
 ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ~ See the License for the specific language governing permissions and
 ~ limitations under the License.
 */
package info.jmonit.web.components;

import info.jmonit.web.ui.WebComponent;

import java.io.PrintWriter;
import java.text.DateFormat;
import java.text.NumberFormat;

/**
 * @author <a href="mailto:ndeloof@sourceforge.net">ndeloof</a>
 *
 */
public abstract class AbstractWebComponent implements WebComponent
{


    /** format for dates */
    protected DateFormat dateFormat = DateFormat.getDateTimeInstance(
                DateFormat.SHORT, DateFormat.MEDIUM );
    /** format for numbers */
    protected NumberFormat numberFormat = NumberFormat.getInstance();

    /**
     * Render HTML head for jMonit default Web-UI
     *
     * @param writer output
     */
    protected void head( PrintWriter writer, String title )
    {
        writer.println( "<!DOCTYPE HTML PUBLIC "
                + "'-//W3C//DTD HTML 4.01//EN' "
                + "'http://www.w3.org/TR/html4/strict.dtd'>" );
        writer.println( "<html>" );
        writer.println( "<head>" );
        writer.println( "<title>jMonit " + title + "</title>" );
        writer.println( "<link rel='stylesheet' type='text/css' "
                + "href='resources/styles/jmonit.css'/>" );
        writer.println( "<script type='text/javascript' "
                + "src='resources/scripts/jmonit.js'></script>" );
        writer.println( "</head>" );
        writer.println( "<body>" );
        writer.println( "<h1>" + title + "</h1>" );
    }

    /**
     * Render HTML foot.
     * @param writer output
     */
    public void end( PrintWriter writer )
    {
        writer.println( "<p id='footer'>Powered by jMonit 0.1</p>" );
        writer.println( "</body>" );
        writer.println( "</html>" );
    }

    /**
     * @param dateFormat
     *            the dateFormat to set
     */
    public void setDateFormat( DateFormat dateFormat )
    {
        this.dateFormat = dateFormat;
    }

    /**
     * @param numberFormat
     *            the numberFormat to set
     */
    public void setNumberFormat( NumberFormat numberFormat )
    {
        this.numberFormat = numberFormat;
    }
}
