/*
 ~ Copyright 2006-2007 Nicolas De Loof.
 ~
 ~ Licensed under the Apache License, Version 2.0 (the "License");
 ~ you may not use this file except in compliance with the License.
 ~ You may obtain a copy of the License at
 ~
 ~      http://www.apache.org/licenses/LICENSE-2.0
 ~
 ~ Unless required by applicable law or agreed to in writing, software
 ~ distributed under the License is distributed on an "AS IS" BASIS,
 ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ~ See the License for the specific language governing permissions and
 ~ limitations under the License.
 */
package info.jmonit.web.components;

import info.jmonit.Agregator;
import info.jmonit.Monitor;
import info.jmonit.Monitoring;
import info.jmonit.logger.Logger;
import info.jmonit.logger.LoggerFactory;
import info.jmonit.visitor.MonitorSnapshot;
import info.jmonit.visitor.MonitorVisitor;

import java.io.PrintWriter;
import java.lang.reflect.Method;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * Web component for rendering monitor details and configure it.
 *
 * @author <a href="mailto:ndeloof@sourceforge.net">ndeloof</a>
 *
 */
public class Show extends AbstractWebComponent implements MonitorVisitor
{
    /** Logger */
    private static Logger logger = LoggerFactory.getLogger( Show.class );

    /** output writer */
    private PrintWriter writer;

    /** Monitor to render */
    private Monitor monitor;

    /**
     * ${inheritDoc}
     *
     * @throws Exception
     * @override
     * @see info.jmonit.web.ui.WebComponent#render(javax.servlet.http.HttpServletRequest,
     *      javax.servlet.http.HttpServletResponse)
     */
    public void render( HttpServletRequest request, HttpServletResponse response )
            throws Exception
    {
        this.writer = response.getWriter();
        String domain = request.getParameter( "domain" );
        String name = request.getParameter( "name" );

        this.monitor = Monitoring.getMonitor( domain, name );

        String action = request.getParameter( "action" );
        if ( action == null )
        {
            action = "show";
        }

        if ( logger.isDebugEnabled() )
        {
            logger.debug( "invoke " + action + "() on " + this );
        }
        Method method = getClass().getMethod( action, null );
        method.invoke( this, null );
    }

    /**
     * Render monitor details
     *
     */
    public void show()
    {
        StringBuffer title = new StringBuffer( "Detail for Monitor [" );
        title.append( monitor.getDomain().getName() );
        title.append( ":" );
        title.append( monitor.getName() );
        title.append( "]" );
        head( writer, title.toString() );
        monitor.accept( this );
        end( writer );
    }

    private void actions()
    {
        writer.println( "<form action='Show' method='post'>" );
        writer.println( "<input type='hidden' name='domain' " + "value='"
                + monitor.getDomain().getName() + "'/>" );
        writer.println( "<input type='hidden' name='name' value='"
                + monitor.getName() + "'/>" );
        writer.println( "<ul id='actions'>" );
        writer.println( "<li>" );
        writer.println( "<input type='submit' name='action' value='clear'/>" );
        writer.println( "</li>" );
        writer.println( "</ul>" );
        writer.println( "</form>" );
    }

    /**
     * Clear monitor datas.
     *
     */
    public void clear()
    {
        monitor.clear();
        show();
    }

    public void visit( MonitorSnapshot snapshot )
    {
        writer.println( "<table>" );
        writer.println( "<thead>" );
        writer.println( "<tr>" );
        writer.println( "<th colspan='2'>Value</th>" );
        writer.println( "<th colspan='2'>Use</th>" );
        writer.println( "</tr>" );
        writer.println( "</thead>" );
        writer.println( "<tbody>" );

        writer.println( "<tr>" );
        writer.println( "<th>Total</th>" );
        writer.println( "<td>" + snapshot.getTotal() + "</td>" );
        writer.println( "<th>Hits</th>" );
        writer.println( "<td>" + snapshot.getHits() + "</td>" );
        writer.println( "</tr>" );

        writer.println( "<tr>" );
        writer.println( "<th>Min</th>" );
        writer.println( "<td>" + snapshot.getMin() + "</td>" );
        writer.println( "<th>Active</th>" );
        writer.println( "<td>" + snapshot.getActive() + "</td>" );
        writer.println( "</tr>" );

        writer.println( "<tr>" );
        writer.println( "<th>Max</th>" );
        writer.println( "<td>" + snapshot.getMax() + "</td>" );
        writer.println( "<th>Max active</th>" );
        writer.println( "<td>" + snapshot.getMaxActive() + "</td>" );
        writer.println( "</tr>" );

        writer.println( "<tr>" );
        writer.println( "<th>Average</th>" );
        writer.println( "<td>" + numberFormat.format( snapshot.getAverage() )
                + "</td>" );
        writer.println( "<th>Average active</th>" );
        writer.println( "<td>" + numberFormat.format( snapshot.getLoad() )
                + "</td>" );
        writer.println( "</tr>" );

        writer.println( "<tr>" );
        writer.println( "<td colspan='2' rowspan='2'/>" );
        writer.println( "</td>" );
        writer.println( "<th>First use</th>" );
        writer.println( "<td>" + dateFormat.format( snapshot.getFirstUse() )
                + "</td>" );
        writer.println( "</tr>" );

        writer.println( "<tr>" );
        writer.println( "<th>Last use</th>" );
        writer.println( "<td>" + dateFormat.format( snapshot.getLastUse() )
                + "</td>" );
        writer.println( "</tr>" );

        writer.println( "<tr>" );
        writer.println( "<th>Actions</th>" );
        writer.println( "<td>" );
        actions();
        writer.println( "<td colspan='2' rowspan='2'/>" );
        writer.println( "</tr>" );

        writer.println( "</tbody>" );
        writer.println( "</table>" );
    }

    public void visit( Agregator agregator )
    {
        String role = agregator.getRole();
        if ( !role.equals( Agregator.DEFAULT ) )
        {
            writer.println( "<h2>" + role + "</h2>" );
        }
    }

    public void visit( Monitor monitor )
    {
        // Nop
    }

}
