/*
 ~ Copyright 2006-2007 Nicolas De Loof.
 ~
 ~ Licensed under the Apache License, Version 2.0 (the "License");
 ~ you may not use this file except in compliance with the License.
 ~ You may obtain a copy of the License at
 ~
 ~      http://www.apache.org/licenses/LICENSE-2.0
 ~
 ~ Unless required by applicable law or agreed to in writing, software
 ~ distributed under the License is distributed on an "AS IS" BASIS,
 ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ~ See the License for the specific language governing permissions and
 ~ limitations under the License.
 */
package info.jmonit.web.ui;

import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

/**
 * Abstract class for building a secured controller.
 *
 * @author <a href="mailto:ndeloof@sourceforge.net">ndeloof</a>
 */
public abstract class AbstractSecuredController
    extends SimpleController
{
    /**
     * Creates a digest of password
     *
     * @param password user passwrod
     * @param algorithm the digest algorithm to use
     * @return digest string
     * @throws NoSuchAlgorithmException unsuported algorithm
     */
    protected String digest( String password, String algorithm )
        throws NoSuchAlgorithmException
    {
        byte[] hash = MessageDigest.getInstance( algorithm ).digest( password.getBytes() );
        StringBuffer hashString = new StringBuffer();
        for ( int i = 0; i < hash.length; ++i )
        {
            String hex = Integer.toHexString( hash[i] ).toUpperCase();
            if ( hex.length() == 1 )
            {
                hashString.append( '0' );
                hashString.append( hex.charAt( hex.length() - 1 ) );
            }
            else
            {
                hashString.append( hex.substring( hex.length() - 2 ) );
            }
        }
        password = hashString.toString();
        return password;
    }
}
